2023-11-13 Version: 1.1.0
- Generated python2 2020-01-01 for ddoscoo.

2023-07-19 Version: 1.0.1
- Update sdk.

2022-06-30 Version: 1.0.0
- Update sdk.

2021-02-20 Version: 1.0.0
- AMP Version Change.

